"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createWatchServedFilesMiddleware = createWatchServedFilesMiddleware;

var _path = _interopRequireDefault(require("path"));

var _utils = require("../utils/utils.js");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @typedef {object} WatchServedFilesMiddlewareConfig
 * @property {string} rootDir
 * @property {import('chokidar').FSWatcher} fileWatcher
 */

/**
 * @param {import('koa').Context} ctx
 * @param {WatchServedFilesMiddlewareConfig} cfg
 */
async function watchServedFile(ctx, cfg) {
  // should be a file request
  if (!_path.default.extname(ctx.url)) {
    return;
  }

  if ((0, _utils.isInlineModule)(ctx.url) || (0, _utils.isPolyfill)(ctx.url)) {
    return;
  }

  const filePath = (0, _utils.getRequestFilePath)(ctx, cfg.rootDir);

  if (filePath) {
    cfg.fileWatcher.add(filePath);
  }
}
/**
 * Sets up a middleware which tracks served files and sends a reload message to any
 * active browsers when any of the files change.
 *
 * @param {WatchServedFilesMiddlewareConfig} cfg
 */


function createWatchServedFilesMiddleware(cfg) {
  /** @type {import('koa').Middleware} */
  async function watchServedFilesMiddleware(ctx, next) {
    await next();
    watchServedFile(ctx, cfg);
  }

  return watchServedFilesMiddleware;
}